@@ -13,7 +13,7 @@ aggregate_ppp <- function(ppp_list, stat = "T1"){
 
 #' @importFrom rlang .data
 #' @importFrom magrittr %>%
- 
+
 mpt_treebugs <- function (
   method
   , dataset
@@ -24,10 +24,10 @@ mpt_treebugs <- function (
   , core = NULL
 ){
   all_options <- getOption("MPTmultiverse")
-  
+
   TREEBUGS_MCMC <- all_options$treebugs
   CI_SIZE <- all_options$ci_size
-  
+
   # dlist <- prepare_data(model, data, id = "id", condition = "condition")
   conditions <- unique(data[[condition]])
   parameters <- as.character(MPTinR::check.mpt(model)$parameters)
@@ -35,13 +35,13 @@ mpt_treebugs <- function (
 
   data$id <- data[[id]]
   data$condition <- data[[condition]]
-  
+
   freq_list <- split(data[, col_freq, drop = FALSE], f = data[[condition]])
-  pooling <- switch(method, 
-                    "simple" = "no", 
+  pooling <- switch(method,
+                    "simple" = "no",
                     "simple_pooling" = "complete",
                     "partial")
-  
+
   result_row <- make_results_row(model = model,
                                  dataset = dataset,
                                  pooling = pooling,
@@ -52,7 +52,7 @@ mpt_treebugs <- function (
                                  id = id,
                                  condition = condition,
                                  core = core)
-  
+
   # Homogeneity tests
   result_row$test_homogeneity[[1]] <- dplyr::bind_rows(
     lapply(X = freq_list, FUN = function(x) {
@@ -65,68 +65,88 @@ mpt_treebugs <- function (
     })
     , .id = "condition"
   )
-  
-  
+
+
   if (method == "simple_pooling"){
     method <- "simple"
-    
+
     # pooling: aggregate across participants
     data <- stats::aggregate(data[, col_freq], list(condition = data$condition), sum)
     data[[condition]] <- data$condition
     data[[id]] <- data$id <- as.character(1:nrow(data))
-    if(condition!="condition"){
+    if(condition != "condition"){
       data$condition <- NULL
     }
-    
+
     freq_list <- lapply(freq_list, function(x) as.matrix(colSums(x)))
-  } 
+  }
+
+  # ----------------------------------------------------------------------------
+  # Customize prior if necessary
   if (method == "trait_uncorrelated"){
     method <- "trait"
     prior_args <- list(df = 1, V = NA, xi = "dnorm(0,1)")
   } else {
     prior_args <- NULL
   }
-  
+
+  if (method == "beta") {
+    prior_args <- list(
+      alpha = TREEBUGS_MCMC$prior.beta,
+      beta = TREEBUGS_MCMC$prior.beta
+    )
+  }
+
+  # ----------------------------------------------------------------------------
+  # Run MCMC function from TreeBUGS
   gof_group <- list()
   treebugs_fit <- list()
-  
+
   for (i in seq_along(conditions)){
     cond <- conditions[i]
     sel_condition <- data[[condition]] == conditions[i]
     data_group <- data[sel_condition, col_freq]   #freq_list[[i]]
     rownames(data_group) <- data[[id]][sel_condition]
-    
-    fit_args <- list(eqnfile=model,
+
+    fit_args <- list(eqnfile = model,
                      data = data_group,
                      n.chains = TREEBUGS_MCMC$n.chains,
                      n.iter = TREEBUGS_MCMC$n.iter,
                      n.adapt = TREEBUGS_MCMC$n.adapt,
                      n.burnin = TREEBUGS_MCMC$n.burnin,
                      n.thin = TREEBUGS_MCMC$n.thin)
+    if (method == "betacpp" && gsub(TREEBUGS_MCMC$prior.beta, pattern = " |\t", replacement = "") != "dgamma(1,.1)")
+      stop(
+        'betacpp not compatible with custom priors as defined via mpt_options(prior.beta = "',
+        TREEBUGS_MCMC$prior.beta,
+        '")'
+      )
     if (method %in% c("simple", "betacpp")){
-      fit_args["n.adapt"] <- NULL
+      fit_args$n.adapt <- fit_args$alpha <- fit_args$beta <- NULL
       fit_args <- c(fit_args, cores = unname(all_options$n.CPU))
     }
-    # print(c(fit_args, prior_args))
+
+
     t0 <- Sys.time()
-    treebugs_function <- ifelse(method == "betacpp", 
+    treebugs_function <- ifelse(method == "betacpp",
                                 "TreeBUGS::betaMPTcpp",
                                 paste0("TreeBUGS::", method, "MPT"))
-    treebugs_fit[[i]] <- do.call(eval(parse(text = treebugs_function)), 
+    treebugs_fit[[i]] <- do.call(eval(parse(text = treebugs_function)),
                                  args = c(fit_args, prior_args))
     summ <- treebugs_fit[[i]]$mcmc.summ
-    
-    # continue MCMC sampling (only for betaMPT and traitMPT)
+
+    # --------------------------------------------------------------------------
+    # adaptively continue MCMC sampling (only available for betaMPT and traitMPT)
     ext_cnt <- 0
     try({
       while (
         ext_cnt < TREEBUGS_MCMC$extend_max && method %in% c("beta", "trait") &&
         (any(stats::na.omit(summ[,"Rhat"]) > TREEBUGS_MCMC$Rhat_max)  ||
          any(summ[summ[,"n.eff"] > 0,"n.eff"] < TREEBUGS_MCMC$Neff_min, na.rm = TRUE)) ){
-        cat("Drawing additional samples for method = ", method, 
+        cat("Drawing additional samples for method = ", method,
             ". max(Rhat) = ", round(max(stats::na.omit(summ[summ[,"Rhat"] > 0,"Rhat"])), 2),
             " ; min(n.eff) = ", round(min(summ[summ[,"n.eff"] > 0,"n.eff"], na.rm = TRUE), 1), "\n")
-        
+
         treebugs_fit[[i]] <- TreeBUGS::extendMPT(treebugs_fit[[i]],
                                        n.iter = TREEBUGS_MCMC$n.iter,
                                        n.adapt = TREEBUGS_MCMC$n.adapt)
@@ -134,28 +154,29 @@ mpt_treebugs <- function (
         ext_cnt <- ext_cnt + 1
       }
     })
-    
+
     result_row$estimation[[1]]$time_difference[
       result_row$estimation[[1]]$condition == cond
-    ] <- Sys.time() - t0
+    ] <- difftime(Sys.time(), t0, units = "secs")
 
     # convergence summary (n.eff / Rhat / all estimates)
-    tsum <- tibble::as_tibble(summ) %>% 
+    tsum <- tibble::as_tibble(summ) %>%
       dplyr::mutate(parameter = rownames(summ),
-             condition = as.character(cond)) %>% 
+             condition = as.character(cond)) %>%
       dplyr::select(.data$condition, .data$parameter, .data$Mean : .data$Rhat)
+
     result_row$convergence[[1]] <- dplyr::bind_rows(result_row$convergence[[1]], tsum)
-    
+
     # parameter estimates
     summMPT <- TreeBUGS::summarizeMPT(treebugs_fit[[i]]$runjags$mcmc,
                                       mptInfo = treebugs_fit[[i]]$mptInfo,
                                       probs = CI_SIZE,
                                       summ = treebugs_fit[[i]]$mcmc.summ)
-    
+
     sel_group <- result_row$est_group[[1]]$condition == conditions[i]
     result_row$est_group[[1]][sel_group,-(1:3)] <-
       summMPT$groupParameters$mean[paste0("mean_", parameters),1:6]
-    
+
     if (pooling != "complete"){
       # # old: array filled into data frame
       # result_row$est_indiv[[1]][sel_ind,-(1:4)] <-
@@ -163,7 +184,7 @@ mpt_treebugs <- function (
       sel_ind <- result_row$est_indiv[[1]]$condition == conditions[i]
       dimnames(summMPT$individParameters)$ID <- rownames(data_group)
       tmp <- summMPT$individParameters[parameters,,1:(2+length(CI_SIZE)), drop = FALSE] %>%
-        reshape2::melt() %>% 
+        reshape2::melt() %>%
         tidyr::spread("Statistic", "value")
       tmp$identifiable <- NA
 
@@ -177,7 +198,7 @@ mpt_treebugs <- function (
                     dplyr::select("id", "condition", "parameter", "core"),
                   tmp, by = c("parameter", "id", condition = condition))
     }
-    
+
     gof_group[[i]] <- TreeBUGS::PPP(treebugs_fit[[i]], M = TREEBUGS_MCMC$n.PPP, type = "G2",
                           T2 = pooling != "complete", nCPU = all_options$n.CPU)
 
@@ -193,7 +214,7 @@ mpt_treebugs <- function (
         stat_pred = mean(gof_group[[i]]$T1.pred),
         p = gof_group[[i]]$T1.p
       )
-    
+
     if (pooling != "complete"){
       result_row$gof_group[[1]] <- tibble::add_row(result_row$gof_group[[1]],
                                            condition = cond,
@@ -201,7 +222,7 @@ mpt_treebugs <- function (
                                            stat_obs = mean(gof_group[[i]]$T2.obs),
                                            stat_pred = mean(gof_group[[i]]$T2.pred),
                                            p = gof_group[[i]]$T2.p)
-      
+
       sel_fog_ind <- result_row$gof_indiv[[1]]$condition == conditions[i]
       result_row$gof_indiv[[1]][sel_fog_ind,] <-
         result_row$gof_indiv[[1]][sel_fog_ind,] %>%
@@ -214,33 +235,33 @@ mpt_treebugs <- function (
           p = gof_group[[i]]$ind.T1.p)
     }
   }
-  
+
   # between  subject comparisons
   if (length(conditions) > 1){
     for (i in 1:(length(conditions) - 1)){
       for (j in 2:length(conditions)){
         for(p in parameters){
-          test_between <- TreeBUGS::betweenSubjectMPT(treebugs_fit[[i]], treebugs_fit[[j]], 
+          test_between <- TreeBUGS::betweenSubjectMPT(treebugs_fit[[i]], treebugs_fit[[j]],
                                             par1 = p, stat = "x-y")
-          test_summ <- TreeBUGS::summarizeMCMC(test_between$mcmc, 
-                                               probs = CI_SIZE, 
+          test_summ <- TreeBUGS::summarizeMCMC(test_between$mcmc,
+                                               probs = CI_SIZE,
                                                batchSize = 2)
           bayesp <- mean(do.call("rbind", test_between$mcmc) <= 0)
-          
-          sel_row <- 
+
+          sel_row <-
             result_row$test_between[[1]]$parameter == p &
             result_row$test_between[[1]]$condition1 == conditions[i] &
             result_row$test_between[[1]]$condition2 == conditions[j]
-          
-          result_row$test_between[[1]][sel_row,-(1:4)] <- 
-            c(test_summ[,c("Mean", "SD")], 
+
+          result_row$test_between[[1]][sel_row,-(1:4)] <-
+            c(test_summ[,c("Mean", "SD")],
               p = ifelse(bayesp > .5, 1 - bayesp, bayesp) * 2,  # two-sided Bayesian p values
               test_summ[,2 + seq_along(CI_SIZE)])
         }
       }
     }
   }
-  
+
   # don't save T2 if complete pooling was used ----
   # Why? I think it would be worthwhile
   # Daniel: T2 refers to the covariance matrix, which is not defined for aggregated frequencies.
@@ -250,9 +271,9 @@ mpt_treebugs <- function (
   }
   result_row$gof[[1]]$type <- c("T1", if(pooling!="complete"){"T2"})
   result_row$gof[[1]]$focus <- c("mean", if(pooling!="complete"){"cov"})
-  
+
   result_row$gof[[1]][1,-(1:2)] <- aggregate_ppp(gof_group)
-  
+
   # estimation_time <- unlist(estimation_time)
 
   # result_row$estimation[[1]] <- tibble::tibble(
@@ -264,7 +285,7 @@ mpt_treebugs <- function (
     parnames <- coda::varnames(treebugs_fit[[1]]$runjags$mcmc)
     par_mat <- expand.grid("parameter1" = parameters, "parameter2" = parameters,
                             stringsAsFactors = FALSE)
-    
+
     # Parameter correlations & fungibility
     sel_rho <- grep("rho[", parnames, fixed = TRUE, value = TRUE)
     sel_mean <- grep("mean[", parnames, fixed = TRUE, value = TRUE)
@@ -275,11 +296,11 @@ mpt_treebugs <- function (
                                           batchSize = 2)
       bayesp <- colMeans(do.call("rbind", mcmc) <= 0)
       res <- data.frame(par_mat,
-                        rho_summ[,c("Mean", "SD")], 
+                        rho_summ[,c("Mean", "SD")],
                         p = ifelse(bayesp > .5, 1 - bayesp, bayesp) * 2,  # two-sided Bayesian p values
                         rho_summ[,2 + seq_along(CI_SIZE)])
       colnames(res)[3:9] <- colnames(result_row$est_rho[[1]])[6:12]
-      
+
       samples <- do.call("rbind", treebugs_fit[[i]]$runjags$mcmc[,sel_mean])
       colnames(samples) <- parameters
       rmat <- stats::cor(samples)
@@ -291,13 +312,13 @@ mpt_treebugs <- function (
           result_row$est_rho[[1]]$condition == conditions[i]
         if (sum(sel_row) > 0){
           result_row$est_rho[[1]][sel_row,-(1:5)] <- res[j,-(1:2)]
-          result_row$fungibility[[1]][sel_row, "correlation"] <- rmat[par_mat$parameter1[j], 
+          result_row$fungibility[[1]][sel_row, "correlation"] <- rmat[par_mat$parameter1[j],
                                                                       par_mat$parameter2[j]]
         }
       }
     }
   }
-  
+
   # save model objects to the working directory if requested by user ----
   if(all_options$save_models){
     dataset_name <- gsub("^.*[/\\]","", dataset)
